==> ZendFramework-1.9.1.tar.gz: ZendFramework-1.9.1/externals/dojo/dojo/cldr/nls/fi/gregorian.js <==
({
	"months-format-narrow": [
		"T", 
		"H", 
		"M", 
		"H", 
		"T", 
		"K", 
		"H", 
		"E", 
		"S", 
		"L", 
		"M", 
		"J"
	], 
	"quarters-standAlone-narrow": [
		"1", 
		"2", 
		"3", 
		"4"
	], 
	"field-weekday": "viikonpäivä", 
	"dateFormatItem-yQQQ": "QQQ yyyy", 
	"dateFormatItem-yMEd": "EEE d.M.yyyy", 
	"dateFormatItem-MMMEd": "E d. MMM", 
	"eraNarrow": [
		"eKr.", 
		"jKr."
	], 
	"dateFormat-long": "d. MMMM yyyy", 
	"months-format-wide": [
		"tammikuuta", 
		"helmikuuta", 
		"maaliskuuta", 
		"huhtikuuta", 
		"toukokuuta", 
		"kesäkuuta", 
		"heinäkuuta", 
		"elokuuta", 
		"syyskuuta", 
		"lokakuuta", 
		"marraskuuta", 
		"joulukuuta"
	], 
	"dateFormat-full": "EEEE d. MMMM yyyy", 
	"dateFormatItem-Md": "d.M.", 
	"field-era": "aikakausi", 
	"dateFormatItem-yM": "L.yyyy", 
	"months-standAlone-wide": [
		"tammikuuta", 
		"helmikuuta", 
		"maaliskuuta", 
		"huhtikuuta", 
		"toukokuuta", 
		"kesäkuuta", 
		"heinäkuuta", 
		"elokuuta", 
		"syyskuuta", 
		"lokakuuta", 
		"marraskuuta", 
		"joulukuuta"
	], 
	"timeFormat-short": "H.mm", 
	"quarters-format-wide": [
		"1. neljännes", 
		"2. neljännes", 
		"3. neljännes", 
		"4. neljännes"
	], 
	"dateTimeFormat": "{1} {0}", 
	"timeFormat-long": "H.mm.ss z", 
	"field-year": "vuosi", 
	"dateFormatItem-yMMM": "LLL yyyy", 
	"dateFormatItem-yQ": "Q/yyyy", 
	"dateFormatItem-yyyyMMMM": "LLLL yyyy", 
	"field-hour": "tunti", 
	"months-format-abbr": [
		"tammi", 
		"helmi", 
		"maalis", 
		"huhti", 
		"touko", 
		"kesä", 
		"heinä", 
		"elo", 
		"syys", 
		"loka", 
		"marras", 
		"joulu"
	], 
	"dateFormatItem-yyQ": "Q/yy", 
	"patternChars": "GanjkHmsSEDFwWxhKzAeugXZvcL", 
	"timeFormat-full": "H.mm.ss v", 
	"dateFormatItem-yyyyMEEEd": "EEE d.M.yyyy", 
	"am": "ap.", 
	"months-standAlone-abbr": [
		"tammi", 
		"helmi", 
		"maalis", 
		"huhti", 
		"touko", 
		"kesä", 
		"heinä", 
		"elo", 
		"syys", 
		"loka", 
		"marras", 
		"joulu"
	], 
	"quarters-format-abbr": [
		"1. nelj.", 
		"2. nelj.", 
		"3. nelj.", 
		"4. nelj."
	], 
	"quarters-standAlone-wide": [
		"1. neljännes", 
		"2. neljännes", 
		"3. neljännes", 
		"4. neljännes"
	], 
	"dateFormatItem-HHmmss": "HH.mm.ss", 
	"dateFormatItem-M": "L", 
	"days-standAlone-wide": [
		"sunnuntaina", 
		"maanantaina", 
		"tiistaina", 
		"keskiviikkona", 
		"torstaina", 
		"perjantaina", 
		"lauantaina"
	], 
	"dateFormatItem-MMMMd": "d. MMMM", 
	"dateFormatItem-yyMMM": "MMM yy", 
	"timeFormat-medium": "H.mm.ss", 
	"dateFormatItem-Hm": "H.mm", 
	"quarters-standAlone-abbr": [
		"1. nelj.", 
		"2. nelj.", 
		"3. nelj.", 
		"4. nelj."
	], 
	"eraAbbr": [
		"eKr.", 
		"jKr."
	], 
	"field-minute": "minuutti", 
	"field-dayperiod": "ap/ip", 
	"days-standAlone-abbr": [
		"su", 
		"ma", 
		"ti", 
		"ke", 
		"to", 
		"pe", 
		"la"
	], 
	"dateFormatItem-d": "d", 
	"dateFormatItem-ms": "mm.ss", 
	"dateFormatItem-MMMd": "d. MMM", 
	"dateFormatItem-MEd": "E d.M.", 
	"dateFormatItem-yMMMM": "LLLL yyyy", 
	"field-day": "päivä", 
	"days-format-wide": [
		"sunnuntaina", 
		"maanantaina", 
		"tiistaina", 
		"keskiviikkona", 
		"torstaina", 
		"perjantaina", 
		"lauantaina"
	], 
	"field-zone": "aikavyöhyke", 
	"dateFormatItem-y": "yyyy", 
	"months-standAlone-narrow": [
		"T", 
		"H", 
		"M", 
		"H", 
		"T", 
		"K", 
		"H", 
		"E", 
		"S", 
		"L", 
		"M", 
		"J"
	], 
	"dateFormatItem-yyMM": "M/yy", 
	"days-format-abbr": [
		"su", 
		"ma", 
		"ti", 
		"ke", 
		"to", 
		"pe", 
		"la"
	], 
	"eraNames": [
		"ennen Kristuksen syntymää", 
		"jälkeen Kristuksen syntymän"
	], 
	"days-format-narrow": [
		"S", 
		"M", 
		"T", 
		"K", 
		"T", 
		"P", 
		"L"
	], 
	"field-month": "kuukausi", 
	"days-standAlone-narrow": [
		"S", 
		"M", 
		"T", 
		"K", 
		"T", 
		"P", 
		"L"
	], 
	"dateFormatItem-MMM": "LLL", 
	"dateFormatItem-HHmm": "HH.mm", 
	"pm": "ip.", 
	"dateFormatItem-MMMMEd": "E d. MMMM", 
	"dateFormat-short": "d.M.yyyy", 
	"field-second": "sekunti", 
	"dateFormatItem-yMMMEd": "EEE d. MMM yyyy", 
	"field-week": "viikko", 
	"dateFormat-medium": "d.M.yyyy", 
	"dateFormatItem-yyyyM": "M/yyyy", 
	"dateFormatItem-mmss": "mm.ss", 
	"dateFormatItem-yyyyQQQQ": "QQQQ yyyy"
})

==> ZendFramework-1.12.9.tar.gz: ZendFramework-1.12.9/externals/dojo/dojo/cldr/nls/fi/gregorian.js <==
({
	"months-format-narrow": [
		"T", 
		"H", 
		"M", 
		"H", 
		"T", 
		"K", 
		"H", 
		"E", 
		"S", 
		"L", 
		"M", 
		"J"
	], 
	"field-weekday": "viikonpäivä", 
	"dateFormatItem-yQQQ": "QQQ y", 
	"dateFormatItem-yMEd": "EEE d.M.yyyy", 
	"dateFormatItem-MMMEd": "E d. MMM", 
	"eraNarrow": [
		"eKr.", 
		"jKr."
	], 
	"dateFormat-long": "d. MMMM y", 
	"months-format-wide": [
		"tammikuuta", 
		"helmikuuta", 
		"maaliskuuta", 
		"huhtikuuta", 
		"toukokuuta", 
		"kesäkuuta", 
		"heinäkuuta", 
		"elokuuta", 
		"syyskuuta", 
		"lokakuuta", 
		"marraskuuta", 
		"joulukuuta"
	], 
	"dateFormatItem-EEEd": "EEE d.", 
	"dayPeriods-format-wide-pm": "ip.", 
	"dateFormat-full": "EEEE d. MMMM y", 
	"dateFormatItem-Md": "d.M.", 
	"dayPeriods-standAlone-wide-pm": "ip.", 
	"dayPeriods-format-abbr-am": "ap.", 
	"field-era": "aikakausi", 
	"dateFormatItem-yM": "L.yyyy", 
	"months-standAlone-wide": [
		"tammikuu", 
		"helmikuu", 
		"maaliskuu", 
		"huhtikuu", 
		"toukokuu", 
		"kesäkuu", 
		"heinäkuu", 
		"elokuu", 
		"syyskuu", 
		"lokakuu", 
		"marraskuu", 
		"joulukuu"
	], 
	"timeFormat-short": "H.mm", 
	"quarters-format-wide": [
		"1. neljännes", 
		"2. neljännes", 
		"3. neljännes", 
		"4. neljännes"
	], 
	"timeFormat-long": "H.mm.ss z", 
	"field-year": "vuosi", 
	"dateFormatItem-yMMM": "LLL y", 
	"dateFormatItem-yQ": "Q/yyyy", 
	"dateFormatItem-yyyyMMMM": "LLLL y", 
	"field-hour": "tunti", 
	"months-format-abbr": [
		"tammikuuta", 
		"helmikuuta", 
		"maaliskuuta", 
		"huhtikuuta", 
		"toukokuuta", 
		"kesäkuuta", 
		"heinäkuuta", 
		"elokuuta", 
		"syyskuuta", 
		"lokakuuta", 
		"marraskuuta", 
		"joulukuuta"
	], 
	"dateFormatItem-yyQ": "Q/yy", 
	"timeFormat-full": "H.mm.ss zzzz", 
	"dateFormatItem-yyyyMEEEd": "EEE d.M.yyyy", 
	"field-day-relative+0": "tänään", 
	"field-day-relative+1": "huomenna", 
	"field-day-relative+2": "ylihuomenna", 
	"dateFormatItem-H": "H", 
	"months-standAlone-abbr": [
		"tammi", 
		"helmi", 
		"maalis", 
		"huhti", 
		"touko", 
		"kesä", 
		"heinä", 
		"elo", 
		"syys", 
		"loka", 
		"marras", 
		"joulu"
	], 
	"quarters-format-abbr": [
		"1. nelj.", 
		"2. nelj.", 
		"3. nelj.", 
		"4. nelj."
	], 
	"quarters-standAlone-wide": [
		"1. neljännes", 
		"2. neljännes", 
		"3. neljännes", 
		"4. neljännes"
	], 
	"dateFormatItem-M": "L", 
	"days-standAlone-wide": [
		"sunnuntai", 
		"maanantai", 
		"tiistai", 
		"keskiviikko", 
		"torstai", 
		"perjantai", 
		"lauantai"
	], 
	"dateFormatItem-yyMMM": "LLLL yy", 
	"timeFormat-medium": "H.mm.ss", 
	"dateFormatItem-Hm": "H.mm", 
	"quarters-standAlone-abbr": [
		"1. nelj.", 
		"2. nelj.", 
		"3. nelj.", 
		"4. nelj."
	], 
	"eraAbbr": [
		"eKr.", 
		"jKr."
	], 
	"field-minute": "minuutti", 
	"field-dayperiod": "ap./ip.", 
	"days-standAlone-abbr": [
		"su", 
		"ma", 
		"ti", 
		"ke", 
		"to", 
		"pe", 
		"la"
	], 
	"dateFormatItem-d": "d", 
	"dateFormatItem-ms": "mm.ss", 
	"field-day-relative+-1": "eilen", 
	"field-day-relative+-2": "toissapäivänä", 
	"dateFormatItem-MMMd": "d. MMM", 
	"dateFormatItem-MEd": "E d.M.", 
	"field-day": "päivä", 
	"dateFormatItem-yMMMMccccd": "cccc, d. MMMM y", 
	"days-format-wide": [
		"sunnuntaina", 
		"maanantaina", 
		"tiistaina", 
		"keskiviikkona", 
		"torstaina", 
		"perjantaina", 
		"lauantaina"
	], 
	"field-zone": "aikavyöhyke", 
	"dateFormatItem-y": "y", 
	"months-standAlone-narrow": [
		"T", 
		"H", 
		"M", 
		"H", 
		"T", 
		"K", 
		"H", 
		"E", 
		"S", 
		"L", 
		"M", 
		"J"
	], 
	"dateFormatItem-yyMM": "M/yy", 
	"dateFormatItem-hm": "h.mm a", 
	"dayPeriods-format-abbr-pm": "ip.", 
	"days-format-abbr": [
		"su", 
		"ma", 
		"ti", 
		"ke", 
		"to", 
		"pe", 
		"la"
	], 
	"eraNames": [
		"ennen Kristuksen syntymää", 
		"jälkeen Kristuksen syntymän"
	], 
	"days-format-narrow": [
		"S", 
		"M", 
		"T", 
		"K", 
		"T", 
		"P", 
		"L"
	], 
	"field-month": "kuukausi", 
	"days-standAlone-narrow": [
		"S", 
		"M", 
		"T", 
		"K", 
		"T", 
		"P", 
		"L"
	], 
	"dateFormatItem-MMM": "LLL", 
	"dayPeriods-format-wide-am": "ap.", 
	"dayPeriods-standAlone-wide-am": "ap.", 
	"dateFormat-short": "d.M.yyyy", 
	"field-second": "sekunti", 
	"dateFormatItem-yMMMEd": "EEE d. MMM y", 
	"field-week": "viikko", 
	"dateFormat-medium": "d.M.yyyy", 
	"dateFormatItem-yyyyM": "M/yyyy", 
	"dateFormatItem-yyyyQQQQ": "QQQQ y", 
	"dateFormatItem-Hms": "H.mm.ss", 
	"dateFormatItem-hms": "h.mm.ss a"
})
